@@ -74,7 +74,7 @@ def decompress(file_obj, compression="gzip"):
         `version`: 1.0
         `method_name`: decompress
     '''
-    file_list = _gen_path_list(file_obj)
+    file_list = gen_path_list(file_obj)
     result_list = []
     if len(file_list) > 0:
         for file in file_list:
@@ -106,7 +106,7 @@ def compress(file_obj):
         `version`: 1.0
         `method_name`: compress
     '''
-    file_list = _gen_path_list(file_obj)
+    file_list = gen_path_list(file_obj)
     if len(file_list) > 0:
         for file_path in file_list:
             _compress_single_file_gzip(file_path)
@@ -228,7 +228,7 @@ def delete(file_path, **kwargs):
     max_threads = obj.get_kwarg(["max_threads"], 15, (int), **kwargs)
     min_thread_threshold = obj.get_kwarg(["min thread threshold", "min files thread"], 100, (int), **kwargs)
 
-    file_list = _gen_path_list(file_path)
+    file_list = gen_path_list(file_path)
     # print("file_list: ", json.dumps(file_list, indent=4))
     # exit()
     if len(file_list) > 0:
@@ -246,7 +246,7 @@ def delete(file_path, **kwargs):
     return True
 
 
-def _gen_path_list(file_obj):
+def gen_path_list(file_obj):
     '''
         Generates a list of file paths from the mixed type object provided.
 
@@ -269,7 +269,7 @@ def _gen_path_list(file_obj):
         `created`: 12-10-2021 10:08:53
         `memberOf`: file
         `version`: 1.0
-        `method_name`: _gen_path_list
+        `method_name`: gen_path_list
     '''
     file_list = []
 
